==> err_delete-1.0.1.tar.gz: err_delete/src/Form/ErrDeleteForm.php <==
<?php
namespace Drupal\err_delete\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Form\ConfigFormBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use \Drupal\Core\Entity\EntityTypeManagerInterface;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityHandlerInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\FieldableEntityInterface;

use Drupal\Core\StringTranslation\TranslationManager;
use Drupal\Core\Url;


class ErrDeleteForm extends FormBase {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity type bundle info service.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   */
  protected $entityTypeBundleInfo;

  /**
   * The immutable entity clone settings configuration entity.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The editable entity clone settings configuration entity.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $editableConfig;


  
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'err_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state,EntityInterface $node = NULL) {
    /* dpm($node);
    $node_storage = \Drupal::service('entity_type.manager')->getStorage('node');
    $node = $node_storage->load(26); */
    $entity = $node;

    $form = array_merge($form,getFormElement($node));

    $form['actions'] = ['#type' => 'actions'];
      $form['actions']['delete'] = [
        '#type' => 'submit',
        '#button_type' => 'primary',
        '#value' => t('Delete'),
      ];

   $form['delete_node_id'] = $node;

    return ($form);
  }
/**
   * Get all content entity types.
   *
   * @return \Drupal\Core\Entity\ContentEntityTypeInterface[]
   *   An array containing all content entity types.
   */

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state, $node = NULL) {
    $values = $form_state->cleanValues()->getValues();
    $form['delete_node_id']->delete();
    deleteRefEntities($values);
    /* foreach($values['recursive'] as $field_name => $field){
      foreach($field['references'] as $ref_id => $ref_values){
        dpm($ref_values);
      }
    } */
    $dest_url = "/admin/content";
    $url = Url::fromUri('internal:' . $dest_url);
    $form_state->setRedirectUrl($url);
  }

}

==> err_delete-1.0.2.tar.gz: err_delete/src/Form/ErrDeleteForm.php <==
<?php

namespace Drupal\err_delete\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

class ErrDeleteForm extends FormBase {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity type bundle info service.
   *
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   */
  protected $entityTypeBundleInfo;

  /**
   * The immutable entity clone settings configuration entity.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The editable entity clone settings configuration entity.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $editableConfig;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'err_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, EntityInterface $node = NULL) {
    /**
     *  @var EntityInterface $node
     * 
     *  @filesource
     */
    $form = array_merge($form, getFormElement($node));

    $form['actions']           = ['#type' => 'actions'];
    $form['actions']['delete'] = [
      '#type' => 'submit',
      '#button_type' => 'primary',
      '#value' => t('Delete'),
    ];

    $form['delete_node_id'] = $node;

    return ($form);
  }

  /**
   * Get all content entity types.
   *
   * @return \Drupal\Core\Entity\ContentEntityTypeInterface[]
   *   An array containing all content entity types.
   */

  /**
   * {@inheritdoc}
   * 
   * @filesource
   * 
   * @return void
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->cleanValues()->getValues();
    $form['delete_node_id']->delete();
    deleteRefEntities($values);
    $dest_url = '/admin/content';
    $url      = Url::fromUri('internal:' . $dest_url);
    $form_state->setRedirectUrl($url);
  }

}
